<?php
defined( 'ABSPATH' ) or die();
//Custom Donations Configuration Page Class.
class CustomDonations_Configuration {

    private $config, $config_page;

    function __construct() {
        add_action('admin_menu', [$this, 'customdonations_configuration_page']);
        add_action('admin_init', [$this, 'customdonations_settings_init']);
        add_action('admin_enqueue_scripts', [$this, 'customdonations_config_load_scripts']);
        $this->config = get_option('customdonations_options');
    }

    /**
     * Adds settings fields and sections so the configuration page will be processed correctly.
     */
    function customdonations_settings_init() {
        register_setting('customdonations', 'customdonations_options');
        add_settings_section('customdonations_section_loggedin', __('Logged-in User Options', 'customdonations'), null, 'customdonations');
        add_settings_field('customdonations_memberid_enabled', __('Fill a value for <em>memberId</em> when a logged-in user donates?', 'customdonations'), [$this, 'customdonations_field_memberid_enabled_callback'], 'customdonations', 'customdonations_section_loggedin', ['label_for' => 'customdonations_memberid_enabled', 'class' => 'customdonations_memberid_enabled_row', 'customdonations_custom_data' => 'custom']);
        add_settings_field('customdonations_memberid_field', __('The following field will be used as memberId for logged-in users:', 'customdonations'), [$this, 'customdonations_field_memberid_field_callback'], 'customdonations', 'customdonations_section_loggedin', ['label_for' => 'customdonations_memberid_field', 'class' => 'customdonations_memberid_field_row', 'customdonations_custom_data' => 'custom']);
        add_settings_field('customdonations_firsttime', '', [$this, 'customdonations_field_firsttime_callback'], 'customdonations', 'customdonations_section_loggedin', ['label_for' => 'customdonations_firsttime', 'customdonations_custom_data' => 'custom']);
        add_settings_section('customdonations_section_account', __('Optional Settings', 'customdonations'), null, 'customdonations');
        add_settings_field('customdonations_acctid', __('Account', 'customdonations'), [$this, 'customdonations_field_account_callback'], 'customdonations', 'customdonations_section_account', ['label_for' => 'customdonations_acctid', 'class' => 'customdonations_account_row', 'customdonations_custom_data' => 'custom']);
        //add_settings_field('customdonations_paymentver', __('Default Payment Version', 'customdonations'), [$this, 'customdonations_paymentver_callback'],'customdonations','customdonations_section_account', ['label_for' => 'customdonations_paymentver', 'class' => 'customdonations_account_row', 'customdonations_custom_data' => 'custom']);
    }

    /**
     * Render the checkbox that allows the memberid field to be enabled/disabled.
     */
    function customdonations_field_memberid_enabled_callback($args) {
        $checked_orig = !isset($this->config[$args['label_for']]) ? false : $this->config[$args['label_for']];
        $value = is_null($this->config['customdonations_firsttime']) ? 'on' : $checked_orig; //value is true by default - if there is ever a save, then the value provided in that save is the value we will go with.
        ?>
        <input type=checkbox id="<?php echo esc_attr($args['label_for']); ?>" name="customdonations_options[<?php echo esc_attr($args['label_for']); ?>]" <?php checked($value, 'on') ?>>
        <?php
    }

    /**
     * Render the select box for which memberId field should be used.
     */
    function customdonations_field_memberid_field_callback($args) {
        ?>
        <select id="<?php echo esc_attr($args['label_for']); ?>" name="customdonations_options[<?php echo esc_attr($args['label_for']); ?>]"
                >
            <option value="id" <?php echo isset($this->config[$args['label_for']]) ? ( selected($this->config[$args['label_for']], 'id', false) ) : ( '' ); ?>>
                <?php esc_html_e('ID', 'customdonations'); ?>
            </option>
            <option value="user_login" <?php echo isset($this->config[$args['label_for']]) ? ( selected($this->config[$args['label_for']], 'user_login', false) ) : ( '' ); ?>>
                <?php esc_html_e('Username', 'customdonations'); ?>
            </option>
            <option value="user_email" <?php echo isset($this->config[$args['label_for']]) ? ( selected($this->config[$args['label_for']], 'user_email', false) ) : ( '' ); ?>>
                <?php esc_html_e('Email', 'customdonations'); ?>
            </option>
            <option value="display_name" <?php echo isset($this->config[$args['label_for']]) ? ( selected($this->config[$args['label_for']], 'display_name', false) ) : ( '' ); ?>>
                <?php esc_html_e('Display Name', 'customdonations'); ?>
            </option>
        </select>
        <?php
        $this->customdonations_field_memberid_field_examples();
    }

    /**
     * Display examples of what the memberId field values would look like for the logged-in admin if they donated.
     */
    function customdonations_field_memberid_field_examples() {
        $user_info = wp_get_current_user();
        ?>
        <p id="customdonations_memberid_field_examples" class="description">
            <strong>Examples</strong>
        <ul>
            <li>
                <?php echo __(sprintf('ID: %d <strong>(Default)</strong>', $user_info->ID), 'customdonations'); ?>
            </li>
            <li>
                <?php echo __(sprintf('Username: %s', $user_info->user_login), 'customdonations'); ?>
            </li>
            <li>
                <?php echo __(sprintf('Email: %s', $user_info->user_email), 'customdonations'); ?>
            </li>
            <li>
                <?php echo __(sprintf('Display Name: %s', $user_info->display_name), 'customdonations'); ?>
            </li>
        </ul>
        <?php
    }

    /**
     * Hidden field which will flag the configuration page as submitted after the first time.
     */
    function customdonations_field_firsttime_callback($args) {
        ?>
        <input type=hidden id="<?php echo esc_attr($args['label_for']); ?>" name="customdonations_options[<?php echo esc_attr($args['label_for']); ?>]" value="false">
        <?php
    }

    /**
     * Provide the input for the account field.
     */
    function customdonations_field_account_callback($args) {
        ?>
        <input id="<?php echo esc_attr($args['label_for']); ?>" name="customdonations_options[<?php echo esc_attr($args['label_for']); ?>]" value="<?php echo esc_attr($this->config[$args['label_for']]); ?>">
        <p class="description">
            <?php esc_html_e('Providing your Account ID here will allow you to use the shortcode without needing to provide the "account" field', 'customdonations'); ?>
        </p>
        <?php
    }
    
    /**
     * Allows the paymentVersion to have a different default, if the user wants to use inline forms across their site.
     */
    /*function customdonations_paymentver_callback($args){
        ?>
        <select id="<?php echo esc_attr($args['label_for']); ?>" name="customdonations_options[<?php echo esc_attr($args['label_for']); ?>]"
                >
            <option value="1" <?php echo isset($this->config[$args['label_for']]) ? ( selected($this->config[$args['label_for']], 1, false) ) : ( '' ); ?>>
                <?php esc_html_e('Modal Window', 'customdonations'); ?>
            </option>
            <option value="2" <?php echo isset($this->config[$args['label_for']]) ? ( selected($this->config[$args['label_for']], 2, false) ) : ( '' ); ?>>
                <?php esc_html_e('Inline (US Clients Only)', 'customdonations'); ?>
            </option>
        </select>
        <p class="description">
            <?php esc_html_e('You may set the default payment form type for existing shortcodes which do not have "paymentVersion" specified.', 'customdonations'); ?>
        </p>
        <?php
    }*/

    /**
     * Add top-level menu for the Custom Donations Configuration page.
     */
    function customdonations_configuration_page() {
        $this->config_page = add_menu_page('Shortcode Configuration', 'CustomDonations', 'manage_options', 'customdonations', [$this, 'customdonations_configuration_page_html'], plugins_url('../cd-logo-sq.svg', __FILE__));
    }

    /**
     * Add the Javascript for the configuration page - when the configuration page is loaded.
     */
    function customdonations_config_load_scripts($hook) {

        if ($hook != $this->config_page) { //if the custom donations page isn't currently loaded, do nothing here - and just return.
            return;
        }
        wp_enqueue_script('customdonations-config-js', plugins_url('../js/cd-config-page.js', __FILE__));
    }

    /**
     * Triggers when the configuration page is accessed.
     */
    function customdonations_configuration_page_html() {
        //is the user able to manage options? if not they shouldn't be here!
        if (!current_user_can('manage_options')) {
            return;
        }
        //did we get updated settings?
        if (isset($_GET['settings-updated'])) {
            add_settings_error('customdonations_messages', 'customdonations_message', __('Settings Saved', 'customdonations'), 'updated');
        }
        settings_errors('customdonations_messages');
        ?>
        <div class="wrap">
            <div id="cd-title">
                <img id="cd-logo" style="display:inline" src="<?php echo plugins_url('../cd-logo.png', __FILE__); ?>" height="51px" width="300px" alt="CustomDonations logo"/>
                <div style="clear:both;"><br /></div> 
            </div>
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <div style="clear:both;"><br /></div> 
            <form action="options.php" method="post">
                <?php
                settings_fields('customdonations');
                do_settings_sections('customdonations');
                submit_button('Save Settings');
                ?>
            </form>
        </div>
        <?php
    }

}

new CustomDonations_Configuration;
